==> hs-epic-0.9.2.tbz: lib/ghc-7.0.4/cabal/epic-0.9.2/register.sh <==
#!/bin/sh
echo 'name: epic
version: 0.9.2
id: epic-0.9.2-ec4375593511342259edc7b5f33e91db

license: BSD3
copyright:
maintainer: eb@dcs.st-and.ac.uk
stability: experimental
homepage: http://www.dcs.st-and.ac.uk/~eb/epic.php
package-url:
description: Epic is a simple functional language which compiles to
             reasonably efficient C code, using the Boehm-Demers-Weiser
             garbage collector (<http://www.hpl.hp.com/personal/Hans_Boehm/gc/>).
             It is intended as a compiler back end, and is currently used
             as a back end for Epigram (<http://www.e-pig.org>) and Idris
             (<http://idris-lang.org/>).
             It can be invoked either as a library or an application.
category: Compilers/Interpreters
author: Edwin Brady
exposed: True
exposed-modules: Epic.Compiler Epic.Epic
hidden-modules: Epic.Bytecode Epic.Parser Epic.Scopecheck
                Epic.Language Epic.Lexer Epic.CodegenC Epic.CodegenStack
                Epic.OTTLang Epic.Simplify Epic.Stackcode Epic.Evaluator Paths_epic
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/epic-0.9.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/epic-0.9.2
              /usr/local/lib
hs-libraries: HSepic-0.9.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Cabal-1.10.2.0-7573b602ef739778d1ccac9a07ee96ac
         array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/epic-0.9.2/html/epic.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/epic-0.9.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-epic-0.9.3_1.tbz: lib/ghc-7.4.1/cabal/epic-0.9.3/register.sh <==
#!/bin/sh
echo 'name: epic
version: 0.9.3
id: epic-0.9.3-dff14f9a5ba80418b58104a490f276c7

license: BSD3
copyright:
maintainer: eb@dcs.st-and.ac.uk
stability: experimental
homepage: http://www.dcs.st-and.ac.uk/~eb/epic.php
package-url:
synopsis: Compiler for a simple functional language
description: Epic is a simple functional language which compiles to
             reasonably efficient C code, using the Boehm-Demers-Weiser
             garbage collector (<http://www.hpl.hp.com/personal/Hans_Boehm/gc/>).
             It is intended as a compiler back end, and is currently used
             as a back end for Epigram (<http://www.e-pig.org>) and Idris
             (<http://idris-lang.org/>).
             It can be invoked either as a library or an application.
category: Compilers/Interpreters
author: Edwin Brady
exposed: True
exposed-modules: Epic.Compiler Epic.Epic
hidden-modules: Epic.Bytecode Epic.Parser Epic.Scopecheck
                Epic.Language Epic.Lexer Epic.CodegenC Epic.CodegenStack
                Epic.OTTLang Epic.Simplify Epic.Stackcode Epic.Evaluator Paths_epic
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/epic-0.9.3
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/epic-0.9.3
              /usr/local/lib
hs-libraries: HSepic-0.9.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: Cabal-1.14.0-ff3a96ac840681a42a3f6519c92d03a3
         array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         directory-1.1.0.2-265c831825d90ce2ca097745b0e621c1
         mtl-2.1.1-801101765c9185fec3b8dbd5355f5550
         process-1.1.0.1-18dadd8ad5fc640f55a7afdc7aace500
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/epic-0.9.3/html/epic.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/epic-0.9.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
